# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
VrmlConverter module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_vrmlconverter.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _VrmlConverter
else:
    import _VrmlConverter

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _VrmlConverter.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _VrmlConverter.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _VrmlConverter.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _VrmlConverter.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _VrmlConverter.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _VrmlConverter.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _VrmlConverter.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _VrmlConverter.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _VrmlConverter.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _VrmlConverter.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _VrmlConverter.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _VrmlConverter.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _VrmlConverter.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _VrmlConverter.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _VrmlConverter.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _VrmlConverter.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _VrmlConverter.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _VrmlConverter:
_VrmlConverter.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _VrmlConverter.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Aspect
import OCC.Core.Quantity
import OCC.Core.Image
import OCC.Core.Graphic3d
import OCC.Core.BVH
import OCC.Core.TopLoc
import OCC.Core.Bnd
import OCC.Core.Media
import OCC.Core.TopoDS
import OCC.Core.Vrml
import OCC.Core.TopTools
import OCC.Core.HLRAlgo
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor

from enum import IntEnum
from OCC.Core.Exception import *

VrmlConverter_NoLight = _VrmlConverter.VrmlConverter_NoLight
VrmlConverter_DirectionLight = _VrmlConverter.VrmlConverter_DirectionLight
VrmlConverter_PointLight = _VrmlConverter.VrmlConverter_PointLight
VrmlConverter_SpotLight = _VrmlConverter.VrmlConverter_SpotLight
VrmlConverter_NoCamera = _VrmlConverter.VrmlConverter_NoCamera
VrmlConverter_PerspectiveCamera = _VrmlConverter.VrmlConverter_PerspectiveCamera
VrmlConverter_OrthographicCamera = _VrmlConverter.VrmlConverter_OrthographicCamera


class VrmlConverter_TypeOfLight(IntEnum):
	VrmlConverter_NoLight = 0
	VrmlConverter_DirectionLight = 1
	VrmlConverter_PointLight = 2
	VrmlConverter_SpotLight = 3
VrmlConverter_NoLight = VrmlConverter_TypeOfLight.VrmlConverter_NoLight
VrmlConverter_DirectionLight = VrmlConverter_TypeOfLight.VrmlConverter_DirectionLight
VrmlConverter_PointLight = VrmlConverter_TypeOfLight.VrmlConverter_PointLight
VrmlConverter_SpotLight = VrmlConverter_TypeOfLight.VrmlConverter_SpotLight

class VrmlConverter_TypeOfCamera(IntEnum):
	VrmlConverter_NoCamera = 0
	VrmlConverter_PerspectiveCamera = 1
	VrmlConverter_OrthographicCamera = 2
VrmlConverter_NoCamera = VrmlConverter_TypeOfCamera.VrmlConverter_NoCamera
VrmlConverter_PerspectiveCamera = VrmlConverter_TypeOfCamera.VrmlConverter_PerspectiveCamera
VrmlConverter_OrthographicCamera = VrmlConverter_TypeOfCamera.VrmlConverter_OrthographicCamera


def Handle_VrmlConverter_Drawer_Create() -> "opencascade::handle< VrmlConverter_Drawer >":
    return _VrmlConverter.Handle_VrmlConverter_Drawer_Create()

def Handle_VrmlConverter_Drawer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< VrmlConverter_Drawer >":
    return _VrmlConverter.Handle_VrmlConverter_Drawer_DownCast(t)

def Handle_VrmlConverter_Drawer_IsNull(t: "opencascade::handle< VrmlConverter_Drawer > const &") -> "bool":
    return _VrmlConverter.Handle_VrmlConverter_Drawer_IsNull(t)

def Handle_VrmlConverter_LineAspect_Create() -> "opencascade::handle< VrmlConverter_LineAspect >":
    return _VrmlConverter.Handle_VrmlConverter_LineAspect_Create()

def Handle_VrmlConverter_LineAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< VrmlConverter_LineAspect >":
    return _VrmlConverter.Handle_VrmlConverter_LineAspect_DownCast(t)

def Handle_VrmlConverter_LineAspect_IsNull(t: "opencascade::handle< VrmlConverter_LineAspect > const &") -> "bool":
    return _VrmlConverter.Handle_VrmlConverter_LineAspect_IsNull(t)

def Handle_VrmlConverter_PointAspect_Create() -> "opencascade::handle< VrmlConverter_PointAspect >":
    return _VrmlConverter.Handle_VrmlConverter_PointAspect_Create()

def Handle_VrmlConverter_PointAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< VrmlConverter_PointAspect >":
    return _VrmlConverter.Handle_VrmlConverter_PointAspect_DownCast(t)

def Handle_VrmlConverter_PointAspect_IsNull(t: "opencascade::handle< VrmlConverter_PointAspect > const &") -> "bool":
    return _VrmlConverter.Handle_VrmlConverter_PointAspect_IsNull(t)

def Handle_VrmlConverter_Projector_Create() -> "opencascade::handle< VrmlConverter_Projector >":
    return _VrmlConverter.Handle_VrmlConverter_Projector_Create()

def Handle_VrmlConverter_Projector_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< VrmlConverter_Projector >":
    return _VrmlConverter.Handle_VrmlConverter_Projector_DownCast(t)

def Handle_VrmlConverter_Projector_IsNull(t: "opencascade::handle< VrmlConverter_Projector > const &") -> "bool":
    return _VrmlConverter.Handle_VrmlConverter_Projector_IsNull(t)

def Handle_VrmlConverter_ShadingAspect_Create() -> "opencascade::handle< VrmlConverter_ShadingAspect >":
    return _VrmlConverter.Handle_VrmlConverter_ShadingAspect_Create()

def Handle_VrmlConverter_ShadingAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< VrmlConverter_ShadingAspect >":
    return _VrmlConverter.Handle_VrmlConverter_ShadingAspect_DownCast(t)

def Handle_VrmlConverter_ShadingAspect_IsNull(t: "opencascade::handle< VrmlConverter_ShadingAspect > const &") -> "bool":
    return _VrmlConverter.Handle_VrmlConverter_ShadingAspect_IsNull(t)

def Handle_VrmlConverter_IsoAspect_Create() -> "opencascade::handle< VrmlConverter_IsoAspect >":
    return _VrmlConverter.Handle_VrmlConverter_IsoAspect_Create()

def Handle_VrmlConverter_IsoAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< VrmlConverter_IsoAspect >":
    return _VrmlConverter.Handle_VrmlConverter_IsoAspect_DownCast(t)

def Handle_VrmlConverter_IsoAspect_IsNull(t: "opencascade::handle< VrmlConverter_IsoAspect > const &") -> "bool":
    return _VrmlConverter.Handle_VrmlConverter_IsoAspect_IsNull(t)
class VrmlConverter_Curve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_Curve_swiginit(self, _VrmlConverter.new_VrmlConverter_Curve())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_Curve

# Register VrmlConverter_Curve in _VrmlConverter:
_VrmlConverter.VrmlConverter_Curve_swigregister(VrmlConverter_Curve)

class VrmlConverter_DeflectionCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_DeflectionCurve_swiginit(self, _VrmlConverter.new_VrmlConverter_DeflectionCurve())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_DeflectionCurve

# Register VrmlConverter_DeflectionCurve in _VrmlConverter:
_VrmlConverter.VrmlConverter_DeflectionCurve_swigregister(VrmlConverter_DeflectionCurve)

class VrmlConverter_Drawer(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _VrmlConverter.VrmlConverter_Drawer_swiginit(self, _VrmlConverter.new_VrmlConverter_Drawer(*args))

    def DeviationCoefficient(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _VrmlConverter.VrmlConverter_Drawer_DeviationCoefficient(self, *args)

    def DisableDrawHiddenLine(self, *args) -> "void":
        r"""
        Sets drawhiddenline = standard_false - the hidden lines are not drawn.

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_DisableDrawHiddenLine(self, *args)

    def Discretisation(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _VrmlConverter.VrmlConverter_Drawer_Discretisation(self, *args)

    def DrawHiddenLine(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if the hidden lines are to be drawn. by default the hidden lines are not drawn.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_Drawer_DrawHiddenLine(self, *args)

    def EnableDrawHiddenLine(self, *args) -> "void":
        r"""
        Sets drawhiddenline = standard_true - the hidden lines are drawn.

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_EnableDrawHiddenLine(self, *args)

    def FreeBoundaryAspect(self, *args) -> "opencascade::handle< VrmlConverter_LineAspect >":
        r"""
        The default values are the same default values from vrml package. these attributes are used by the following algorithms: vrmlconverter_wfshape vrmlconverter_wfdeflectionshape.

        Returns
        -------
        opencascade::handle<VrmlConverter_LineAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_FreeBoundaryAspect(self, *args)

    def FreeBoundaryDraw(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the drawing of the free boundaries is enabled.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_Drawer_FreeBoundaryDraw(self, *args)

    def HiddenLineAspect(self, *args) -> "opencascade::handle< VrmlConverter_LineAspect >":
        r"""
        Returns lineaspect for the hidden lines. the default values are the same default values from vrml package.

        Returns
        -------
        opencascade::handle<VrmlConverter_LineAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_HiddenLineAspect(self, *args)

    def IsoOnPlane(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the drawing of isos on planes is enabled.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_Drawer_IsoOnPlane(self, *args)

    def LineAspect(self, *args) -> "opencascade::handle< VrmlConverter_LineAspect >":
        r"""
        The default values are the same default values from vrml package.

        Returns
        -------
        opencascade::handle<VrmlConverter_LineAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_LineAspect(self, *args)

    def MaximalChordialDeviation(self, *args) -> "Standard_Real":
        r"""
        Returns the maximal chordial deviation. default value: 0.1.

        Returns
        -------
        float

        """
        return _VrmlConverter.VrmlConverter_Drawer_MaximalChordialDeviation(self, *args)

    def MaximalParameterValue(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _VrmlConverter.VrmlConverter_Drawer_MaximalParameterValue(self, *args)

    def PointAspect(self, *args) -> "opencascade::handle< VrmlConverter_PointAspect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<VrmlConverter_PointAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_PointAspect(self, *args)

    def SeenLineAspect(self, *args) -> "opencascade::handle< VrmlConverter_LineAspect >":
        r"""
        Returns lineaspect for the seen lines. the default values are the same default values from vrml package.

        Returns
        -------
        opencascade::handle<VrmlConverter_LineAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_SeenLineAspect(self, *args)

    def SetDeviationCoefficient(self, *args) -> "void":
        r"""
        Default 0.001.

        Parameters
        ----------
        aCoefficient: float

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetDeviationCoefficient(self, *args)

    def SetDiscretisation(self, *args) -> "void":
        r"""
        Default: 17 points. defines the discretisation (mynbpoints) when drawing any curve; if this value is one of the obvious parameters of methods, current value from drawer won't be used. this value is used by: //! vrmlconverter_curve vrmlconverter_wfrestrictedface vrmlconverter_wfshape.

        Parameters
        ----------
        d: int

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetDiscretisation(self, *args)

    def SetFreeBoundaryAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_LineAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetFreeBoundaryAspect(self, *args)

    def SetFreeBoundaryDraw(self, *args) -> "void":
        r"""
        Enables the drawing the free boundaries by default the free boundaries are drawn.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetFreeBoundaryDraw(self, *args)

    def SetHiddenLineAspect(self, *args) -> "void":
        r"""
        Sets lineaspect for the hidden lines.

        Parameters
        ----------
        anAspect: VrmlConverter_LineAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetHiddenLineAspect(self, *args)

    def SetIsoOnPlane(self, *args) -> "void":
        r"""
        Enables the drawing of isos on planes. by default there are no isos on planes.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetIsoOnPlane(self, *args)

    def SetLineAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_LineAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetLineAspect(self, *args)

    def SetMaximalChordialDeviation(self, *args) -> "void":
        r"""
        Defines the maximal chordial deviation when drawing any curve; if this value is one of the obvious parameters of methods, current value from drawer won't be used. this value is used by: //! vrmlconverter_deflectioncurve vrmlconverter_wfdeflectionrestrictedface vrmlconverter_wfdeflectionshape.

        Parameters
        ----------
        aChordialDeviation: float

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetMaximalChordialDeviation(self, *args)

    def SetMaximalParameterValue(self, *args) -> "void":
        r"""
        Defines the maximum value allowed for the first and last parameters of an infinite curve. default value: 500. vrmlconverter_curve vrmlconverter_wfrestrictedface vrmlconverter_wfshape.

        Parameters
        ----------
        Value: float

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetMaximalParameterValue(self, *args)

    def SetPointAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_PointAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetPointAspect(self, *args)

    def SetSeenLineAspect(self, *args) -> "void":
        r"""
        Sets lineaspect for the seen lines.

        Parameters
        ----------
        anAspect: VrmlConverter_LineAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetSeenLineAspect(self, *args)

    def SetShadingAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_ShadingAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetShadingAspect(self, *args)

    def SetTypeOfDeflection(self, *args) -> "void":
        r"""
        By default: tod_relative; however, except for the shapes, the drawing will be made using the absolute deviation.

        Parameters
        ----------
        aTypeOfDeflection: Aspect_TypeOfDeflection

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetTypeOfDeflection(self, *args)

    def SetUIsoAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_IsoAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetUIsoAspect(self, *args)

    def SetUnFreeBoundaryAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_LineAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetUnFreeBoundaryAspect(self, *args)

    def SetUnFreeBoundaryDraw(self, *args) -> "void":
        r"""
        Enables the drawing the unfree boundaries by default the unfree boundaries are drawn.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetUnFreeBoundaryDraw(self, *args)

    def SetVIsoAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_IsoAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetVIsoAspect(self, *args)

    def SetWireAspect(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anAspect: VrmlConverter_LineAspect

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetWireAspect(self, *args)

    def SetWireDraw(self, *args) -> "void":
        r"""
        Enables the drawing the wire by default the wire are drawn.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Drawer_SetWireDraw(self, *args)

    def ShadingAspect(self, *args) -> "opencascade::handle< VrmlConverter_ShadingAspect >":
        r"""
        The default values are the same default values from vrml package.

        Returns
        -------
        opencascade::handle<VrmlConverter_ShadingAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_ShadingAspect(self, *args)

    def TypeOfDeflection(self, *args) -> "Aspect_TypeOfDeflection":
        r"""
        No available documentation.

        Returns
        -------
        Aspect_TypeOfDeflection

        """
        return _VrmlConverter.VrmlConverter_Drawer_TypeOfDeflection(self, *args)

    def UIsoAspect(self, *args) -> "opencascade::handle< VrmlConverter_IsoAspect >":
        r"""
        Defines the attributes which are used when drawing an u isoparametric curve of a face. defines the number of u isoparametric curves to be drawn for a single face. the default values are the same default values from vrml package. //! these attributes are used by the following algorithms: vrmlconverter_wfrestrictedface vrmlconverter_wfdeflectionrestrictedface.

        Returns
        -------
        opencascade::handle<VrmlConverter_IsoAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_UIsoAspect(self, *args)

    def UnFreeBoundaryAspect(self, *args) -> "opencascade::handle< VrmlConverter_LineAspect >":
        r"""
        The default values are the same default values from vrml package. these attributes are used by the following algorithms: vrmlconverter_wfshape vrmlconverter_wfdeflectionshape.

        Returns
        -------
        opencascade::handle<VrmlConverter_LineAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_UnFreeBoundaryAspect(self, *args)

    def UnFreeBoundaryDraw(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the drawing of the unfree boundaries is enabled.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_Drawer_UnFreeBoundaryDraw(self, *args)

    def VIsoAspect(self, *args) -> "opencascade::handle< VrmlConverter_IsoAspect >":
        r"""
        Defines the attributes which are used when drawing an v isoparametric curve of a face. defines the number of v isoparametric curves to be drawn for a single face. the default values are the same default values from vrml package. //! these attributes are used by the following algorithms: vrmlconverter_wfrestrictedface vrmlconverter_wfdeflectionrestrictedface.

        Returns
        -------
        opencascade::handle<VrmlConverter_IsoAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_VIsoAspect(self, *args)

    def WireAspect(self, *args) -> "opencascade::handle< VrmlConverter_LineAspect >":
        r"""
        The default values are the same default values from vrml package. these attributes are used by the following algorithms: vrmlconverter_wfshape vrmlconverter_wfdeflectionshape.

        Returns
        -------
        opencascade::handle<VrmlConverter_LineAspect>

        """
        return _VrmlConverter.VrmlConverter_Drawer_WireAspect(self, *args)

    def WireDraw(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the drawing of the wire is enabled.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_Drawer_WireDraw(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_VrmlConverter_Drawer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_Drawer

# Register VrmlConverter_Drawer in _VrmlConverter:
_VrmlConverter.VrmlConverter_Drawer_swigregister(VrmlConverter_Drawer)

class VrmlConverter_HLRShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_HLRShape_swiginit(self, _VrmlConverter.new_VrmlConverter_HLRShape())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_HLRShape

# Register VrmlConverter_HLRShape in _VrmlConverter:
_VrmlConverter.VrmlConverter_HLRShape_swigregister(VrmlConverter_HLRShape)

class VrmlConverter_LineAspect(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a default lineaspect. default value: hasmaterial = false - a line hasn't own material (color).

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        OnOff: bool

        Returns
        -------
        None

        """
        _VrmlConverter.VrmlConverter_LineAspect_swiginit(self, _VrmlConverter.new_VrmlConverter_LineAspect(*args))

    def HasMaterial(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the materials is writing into ostream.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_LineAspect_HasMaterial(self, *args)

    def Material(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlConverter.VrmlConverter_LineAspect_Material(self, *args)

    def SetHasMaterial(self, *args) -> "void":
        r"""
        Defines the necessary of writing own material from vrml into output ostream. by default false - the material is not writing into ostream, true - the material is writing.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_LineAspect_SetHasMaterial(self, *args)

    def SetMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_LineAspect_SetMaterial(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_VrmlConverter_LineAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_LineAspect

# Register VrmlConverter_LineAspect in _VrmlConverter:
_VrmlConverter.VrmlConverter_LineAspect_swigregister(VrmlConverter_LineAspect)

class VrmlConverter_PointAspect(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a default pointaspect. default value: hasmaterial = false - a line hasn't own material (color).

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        OnOff: bool

        Returns
        -------
        None

        """
        _VrmlConverter.VrmlConverter_PointAspect_swiginit(self, _VrmlConverter.new_VrmlConverter_PointAspect(*args))

    def HasMaterial(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the materials is writing into ostream.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_PointAspect_HasMaterial(self, *args)

    def Material(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlConverter.VrmlConverter_PointAspect_Material(self, *args)

    def SetHasMaterial(self, *args) -> "void":
        r"""
        Defines the necessary of writing own material from vrml into output ostream. by default false - the material is not writing into ostream, true - the material is writing.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_PointAspect_SetHasMaterial(self, *args)

    def SetMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_PointAspect_SetMaterial(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_VrmlConverter_PointAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_PointAspect

# Register VrmlConverter_PointAspect in _VrmlConverter:
_VrmlConverter.VrmlConverter_PointAspect_swigregister(VrmlConverter_PointAspect)

class VrmlConverter_Projector(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Shapes: TopTools_Array1OfShape
        Focus: float
        DX: float
        DY: float
        DZ: float
        XUp: float
        YUp: float
        ZUp: float
        Camera: VrmlConverter_TypeOfCamera,optional
        	default value is VrmlConverter_NoCamera
        Light: VrmlConverter_TypeOfLight,optional
        	default value is VrmlConverter_NoLight

        Returns
        -------
        None

        """
        _VrmlConverter.VrmlConverter_Projector_swiginit(self, _VrmlConverter.new_VrmlConverter_Projector(*args))

    def AddToString(self) -> "std::string":
        r"""AddToString(VrmlConverter_Projector self) -> std::string"""
        return _VrmlConverter.VrmlConverter_Projector_AddToString(self)

    def Camera(self, *args) -> "VrmlConverter_TypeOfCamera":
        r"""
        No available documentation.

        Returns
        -------
        VrmlConverter_TypeOfCamera

        """
        return _VrmlConverter.VrmlConverter_Projector_Camera(self, *args)

    def Light(self, *args) -> "VrmlConverter_TypeOfLight":
        r"""
        No available documentation.

        Returns
        -------
        VrmlConverter_TypeOfLight

        """
        return _VrmlConverter.VrmlConverter_Projector_Light(self, *args)

    def Projector(self, *args) -> "HLRAlgo_Projector":
        r"""
        No available documentation.

        Returns
        -------
        HLRAlgo_Projector

        """
        return _VrmlConverter.VrmlConverter_Projector_Projector(self, *args)

    def SetCamera(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aCamera: VrmlConverter_TypeOfCamera

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Projector_SetCamera(self, *args)

    def SetLight(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLight: VrmlConverter_TypeOfLight

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_Projector_SetLight(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_VrmlConverter_Projector_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_Projector

# Register VrmlConverter_Projector in _VrmlConverter:
_VrmlConverter.VrmlConverter_Projector_swigregister(VrmlConverter_Projector)

class VrmlConverter_ShadedShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ComputeNormal(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFace: TopoDS_Face
        pc: Poly_Connect
        Nor: TColgp_Array1OfDir

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_ShadedShape_ComputeNormal(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_ShadedShape_swiginit(self, _VrmlConverter.new_VrmlConverter_ShadedShape())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_ShadedShape

# Register VrmlConverter_ShadedShape in _VrmlConverter:
_VrmlConverter.VrmlConverter_ShadedShape_swigregister(VrmlConverter_ShadedShape)

def VrmlConverter_ShadedShape_ComputeNormal(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aFace: TopoDS_Face
    pc: Poly_Connect
    Nor: TColgp_Array1OfDir

    Returns
    -------
    None

    """
    return _VrmlConverter.VrmlConverter_ShadedShape_ComputeNormal(*args)

class VrmlConverter_ShadingAspect(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a default shadingaspect.

        Returns
        -------
        None

        """
        _VrmlConverter.VrmlConverter_ShadingAspect_swiginit(self, _VrmlConverter.new_VrmlConverter_ShadingAspect(*args))

    def FrontMaterial(self, *args) -> "opencascade::handle< Vrml_Material >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Vrml_Material>

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_FrontMaterial(self, *args)

    def HasMaterial(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the materials is writing into ostream.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_HasMaterial(self, *args)

    def HasNormals(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the normals are calculating.

        Returns
        -------
        bool

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_HasNormals(self, *args)

    def SetFrontMaterial(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_SetFrontMaterial(self, *args)

    def SetHasMaterial(self, *args) -> "void":
        r"""
        Defines necessary of writing material from vrml into output ostream. by default false - the material is not writing into ostream, true - the material is writing.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_SetHasMaterial(self, *args)

    def SetHasNormals(self, *args) -> "void":
        r"""
        Defines necessary of a calculation of normals for shadedshape to more accurately display curved surfaces, pacticularly when smoooth or phong shading is used in vrml viewer. by default false - the normals are not calculated, true - the normals are calculated. warning: if normals are calculated the resulting vrml file will be substantially lager.

        Parameters
        ----------
        OnOff: bool

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_SetHasNormals(self, *args)

    def SetShapeHints(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aShapeHints: Vrml_ShapeHints

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_SetShapeHints(self, *args)

    def ShapeHints(self, *args) -> "Vrml_ShapeHints":
        r"""
        No available documentation.

        Returns
        -------
        Vrml_ShapeHints

        """
        return _VrmlConverter.VrmlConverter_ShadingAspect_ShapeHints(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_VrmlConverter_ShadingAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_ShadingAspect

# Register VrmlConverter_ShadingAspect in _VrmlConverter:
_VrmlConverter.VrmlConverter_ShadingAspect_swigregister(VrmlConverter_ShadingAspect)

class VrmlConverter_WFDeflectionRestrictedFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_WFDeflectionRestrictedFace_swiginit(self, _VrmlConverter.new_VrmlConverter_WFDeflectionRestrictedFace())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_WFDeflectionRestrictedFace

# Register VrmlConverter_WFDeflectionRestrictedFace in _VrmlConverter:
_VrmlConverter.VrmlConverter_WFDeflectionRestrictedFace_swigregister(VrmlConverter_WFDeflectionRestrictedFace)

class VrmlConverter_WFDeflectionShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_WFDeflectionShape_swiginit(self, _VrmlConverter.new_VrmlConverter_WFDeflectionShape())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_WFDeflectionShape

# Register VrmlConverter_WFDeflectionShape in _VrmlConverter:
_VrmlConverter.VrmlConverter_WFDeflectionShape_swigregister(VrmlConverter_WFDeflectionShape)

class VrmlConverter_WFRestrictedFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_WFRestrictedFace_swiginit(self, _VrmlConverter.new_VrmlConverter_WFRestrictedFace())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_WFRestrictedFace

# Register VrmlConverter_WFRestrictedFace in _VrmlConverter:
_VrmlConverter.VrmlConverter_WFRestrictedFace_swigregister(VrmlConverter_WFRestrictedFace)

class VrmlConverter_WFShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _VrmlConverter.VrmlConverter_WFShape_swiginit(self, _VrmlConverter.new_VrmlConverter_WFShape())
    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_WFShape

# Register VrmlConverter_WFShape in _VrmlConverter:
_VrmlConverter.VrmlConverter_WFShape_swigregister(VrmlConverter_WFShape)

class VrmlConverter_IsoAspect(VrmlConverter_LineAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a default isoaspect. default value: mynumber - 10.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        aMaterial: Vrml_Material
        OnOff: bool
        aNumber: int

        Returns
        -------
        None

        """
        _VrmlConverter.VrmlConverter_IsoAspect_swiginit(self, _VrmlConverter.new_VrmlConverter_IsoAspect(*args))

    def Number(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of u or v isoparametric curves drawn for a single face.

        Returns
        -------
        int

        """
        return _VrmlConverter.VrmlConverter_IsoAspect_Number(self, *args)

    def SetNumber(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aNumber: int

        Returns
        -------
        None

        """
        return _VrmlConverter.VrmlConverter_IsoAspect_SetNumber(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_VrmlConverter_IsoAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _VrmlConverter.delete_VrmlConverter_IsoAspect

# Register VrmlConverter_IsoAspect in _VrmlConverter:
_VrmlConverter.VrmlConverter_IsoAspect_swigregister(VrmlConverter_IsoAspect)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ShapeConstruct module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_shapeconstruct.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ShapeConstruct
else:
    import _ShapeConstruct

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ShapeConstruct.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ShapeConstruct.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ShapeConstruct.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ShapeConstruct.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ShapeConstruct.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ShapeConstruct.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ShapeConstruct.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ShapeConstruct.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ShapeConstruct.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ShapeConstruct.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ShapeConstruct.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ShapeConstruct.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ShapeConstruct.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ShapeConstruct.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ShapeConstruct.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ShapeConstruct.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ShapeConstruct.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ShapeConstruct:
_ShapeConstruct.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ShapeConstruct.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d
import OCC.Core.TopAbs
import OCC.Core.TopTools
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopLoc
import OCC.Core.BRepBuilderAPI
import OCC.Core.BRepTools
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.ShapeAnalysis
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom
import OCC.Core.Adaptor3d
import OCC.Core.Adaptor2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.IntRes2d

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_ShapeConstruct_ProjectCurveOnSurface_Create() -> "opencascade::handle< ShapeConstruct_ProjectCurveOnSurface >":
    return _ShapeConstruct.Handle_ShapeConstruct_ProjectCurveOnSurface_Create()

def Handle_ShapeConstruct_ProjectCurveOnSurface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeConstruct_ProjectCurveOnSurface >":
    return _ShapeConstruct.Handle_ShapeConstruct_ProjectCurveOnSurface_DownCast(t)

def Handle_ShapeConstruct_ProjectCurveOnSurface_IsNull(t: "opencascade::handle< ShapeConstruct_ProjectCurveOnSurface > const &") -> "bool":
    return _ShapeConstruct.Handle_ShapeConstruct_ProjectCurveOnSurface_IsNull(t)
class shapeconstruct(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ConvertCurveToBSpline(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        Tool for wire triangulation.

        Parameters
        ----------
        C3D: Geom_Curve
        First: float
        Last: float
        Tol3d: float
        Continuity: GeomAbs_Shape
        MaxSegments: int
        MaxDegree: int

        Returns
        -------
        opencascade::handle<Geom_BSplineCurve>
        No available documentation.

        Parameters
        ----------
        C2D: Geom2d_Curve
        First: float
        Last: float
        Tol2d: float
        Continuity: GeomAbs_Shape
        MaxSegments: int
        MaxDegree: int

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _ShapeConstruct.shapeconstruct_ConvertCurveToBSpline(*args)

    @staticmethod
    def ConvertSurfaceToBSpline(*args) -> "opencascade::handle< Geom_BSplineSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        surf: Geom_Surface
        UF: float
        UL: float
        VF: float
        VL: float
        Tol3d: float
        Continuity: GeomAbs_Shape
        MaxSegments: int
        MaxDegree: int

        Returns
        -------
        opencascade::handle<Geom_BSplineSurface>

        """
        return _ShapeConstruct.shapeconstruct_ConvertSurfaceToBSpline(*args)

    @staticmethod
    def JoinCurves(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &, Standard_Boolean &, Standard_Boolean &":
        r"""
        Method for joininig curves 3d. parameters : c3d1,ac3d2 - initial curves orient1, orient2 - initial edges orientations. first1,last1,first2,last2 - parameters for trimming curves (re-calculate with account of orientation edges) c3dout - result curve isrev1,isrev2 - out parameters indicative on possible errors. return value : true - if curves were joined successfully, else - false.

        Parameters
        ----------
        c3d1: Geom_Curve
        ac3d2: Geom_Curve
        Orient1: TopAbs_Orientation
        Orient2: TopAbs_Orientation
        c3dOut: Geom_Curve

        Returns
        -------
        first1: float
        last1: float
        first2: float
        last2: float
        isRev1: bool
        isRev2: bool
        Method for joininig curves 3d. parameters : c3d1,ac3d2 - initial curves orient1, orient2 - initial edges orientations. first1,last1,first2,last2 - parameters for trimming curves (re-calculate with account of orientation edges) c3dout - result curve isrev1,isrev2 - out parameters indicative on possible errors. iserror - input parameter indicative possible errors due to that one from edges have one vertex return value : true - if curves were joined successfully, else - false.

        Parameters
        ----------
        c2d1: Geom2d_Curve
        ac2d2: Geom2d_Curve
        Orient1: TopAbs_Orientation
        Orient2: TopAbs_Orientation
        c2dOut: Geom2d_Curve
        isError: bool,optional
        	default value is Standard_False

        Returns
        -------
        first1: float
        last1: float
        first2: float
        last2: float
        isRev1: bool
        isRev2: bool

        """
        return _ShapeConstruct.shapeconstruct_JoinCurves(*args)

    @staticmethod
    def JoinPCurves(*args) -> "Standard_Boolean":
        r"""
        Join pcurves of the <theedge> on the <theface> try to use pcurves from originas edges <theedges> returns false if cannot join pcurves.

        Parameters
        ----------
        theEdges: TopTools_HSequenceOfShape
        theFace: TopoDS_Face
        theEdge: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _ShapeConstruct.shapeconstruct_JoinPCurves(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeConstruct.shapeconstruct_swiginit(self, _ShapeConstruct.new_shapeconstruct())
    __swig_destroy__ = _ShapeConstruct.delete_shapeconstruct

# Register shapeconstruct in _ShapeConstruct:
_ShapeConstruct.shapeconstruct_swigregister(shapeconstruct)

def shapeconstruct_ConvertCurveToBSpline(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
    r"""
    Tool for wire triangulation.

    Parameters
    ----------
    C3D: Geom_Curve
    First: float
    Last: float
    Tol3d: float
    Continuity: GeomAbs_Shape
    MaxSegments: int
    MaxDegree: int

    Returns
    -------
    opencascade::handle<Geom_BSplineCurve>
    No available documentation.

    Parameters
    ----------
    C2D: Geom2d_Curve
    First: float
    Last: float
    Tol2d: float
    Continuity: GeomAbs_Shape
    MaxSegments: int
    MaxDegree: int

    Returns
    -------
    opencascade::handle<Geom2d_BSplineCurve>

    """
    return _ShapeConstruct.shapeconstruct_ConvertCurveToBSpline(*args)

def shapeconstruct_ConvertSurfaceToBSpline(*args) -> "opencascade::handle< Geom_BSplineSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    surf: Geom_Surface
    UF: float
    UL: float
    VF: float
    VL: float
    Tol3d: float
    Continuity: GeomAbs_Shape
    MaxSegments: int
    MaxDegree: int

    Returns
    -------
    opencascade::handle<Geom_BSplineSurface>

    """
    return _ShapeConstruct.shapeconstruct_ConvertSurfaceToBSpline(*args)

def shapeconstruct_JoinCurves(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &, Standard_Boolean &, Standard_Boolean &":
    r"""
    Method for joininig curves 3d. parameters : c3d1,ac3d2 - initial curves orient1, orient2 - initial edges orientations. first1,last1,first2,last2 - parameters for trimming curves (re-calculate with account of orientation edges) c3dout - result curve isrev1,isrev2 - out parameters indicative on possible errors. return value : true - if curves were joined successfully, else - false.

    Parameters
    ----------
    c3d1: Geom_Curve
    ac3d2: Geom_Curve
    Orient1: TopAbs_Orientation
    Orient2: TopAbs_Orientation
    c3dOut: Geom_Curve

    Returns
    -------
    first1: float
    last1: float
    first2: float
    last2: float
    isRev1: bool
    isRev2: bool
    Method for joininig curves 3d. parameters : c3d1,ac3d2 - initial curves orient1, orient2 - initial edges orientations. first1,last1,first2,last2 - parameters for trimming curves (re-calculate with account of orientation edges) c3dout - result curve isrev1,isrev2 - out parameters indicative on possible errors. iserror - input parameter indicative possible errors due to that one from edges have one vertex return value : true - if curves were joined successfully, else - false.

    Parameters
    ----------
    c2d1: Geom2d_Curve
    ac2d2: Geom2d_Curve
    Orient1: TopAbs_Orientation
    Orient2: TopAbs_Orientation
    c2dOut: Geom2d_Curve
    isError: bool,optional
    	default value is Standard_False

    Returns
    -------
    first1: float
    last1: float
    first2: float
    last2: float
    isRev1: bool
    isRev2: bool

    """
    return _ShapeConstruct.shapeconstruct_JoinCurves(*args)

def shapeconstruct_JoinPCurves(*args) -> "Standard_Boolean":
    r"""
    Join pcurves of the <theedge> on the <theface> try to use pcurves from originas edges <theedges> returns false if cannot join pcurves.

    Parameters
    ----------
    theEdges: TopTools_HSequenceOfShape
    theFace: TopoDS_Face
    theEdge: TopoDS_Edge

    Returns
    -------
    bool

    """
    return _ShapeConstruct.shapeconstruct_JoinPCurves(*args)

class ShapeConstruct_Curve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AdjustCurve(self, *args) -> "Standard_Boolean":
        r"""
        Modifies a curve in order to make its bounds confused with given points. works only on lines and b-splines, returns true in this case, else returns false. for line considers both bounding points, for b-splines only specified. //! warning : does not check if curve should be reversed.

        Parameters
        ----------
        C3D: Geom_Curve
        P1: gp_Pnt
        P2: gp_Pnt
        take1: bool,optional
        	default value is Standard_True
        take2: bool,optional
        	default value is Standard_True

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_Curve_AdjustCurve(self, *args)

    def AdjustCurve2d(self, *args) -> "Standard_Boolean":
        r"""
        Modifies a curve in order to make its bounds confused with given points. works only on lines and b-splines, returns true in this case, else returns false. //! for line considers both bounding points, for b-splines only specified. //! warning : does not check if curve should be reversed.

        Parameters
        ----------
        C2D: Geom2d_Curve
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        take1: bool,optional
        	default value is Standard_True
        take2: bool,optional
        	default value is Standard_True

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_Curve_AdjustCurve2d(self, *args)

    def AdjustCurveSegment(self, *args) -> "Standard_Boolean":
        r"""
        Modifies a curve in order to make its bounds confused with given points. works only on lines and b-splines. //! for lines works as previous method, b-splines are segmented at the given values and then are adjusted to the points.

        Parameters
        ----------
        C3D: Geom_Curve
        P1: gp_Pnt
        P2: gp_Pnt
        U1: float
        U2: float

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_Curve_AdjustCurveSegment(self, *args)

    def ConvertToBSpline(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        Converts a curve of any type (only part from first to last) to bspline. the method of conversion depends on the type of original curve: bspline -> c.segment(first,last) bezier and line -> geomconvert::curvetobsplinecurve(c).segment(first,last) conic and other -> approx_curve3d(c[first,last],prec,c1,9,1000).

        Parameters
        ----------
        C: Geom_Curve
        first: float
        last: float
        prec: float

        Returns
        -------
        opencascade::handle<Geom_BSplineCurve>
        Converts a curve of any type (only part from first to last) to bspline. the method of conversion depends on the type of original curve: bspline -> c.segment(first,last) bezier and line -> geomconvert::curvetobsplinecurve(c).segment(first,last) conic and other -> approx_curve2d(c[first,last],prec,c1,9,1000).

        Parameters
        ----------
        C: Geom2d_Curve
        first: float
        last: float
        prec: float

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _ShapeConstruct.ShapeConstruct_Curve_ConvertToBSpline(self, *args)

    @staticmethod
    def FixKnots(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        knots: TColStd_HArray1OfReal

        Returns
        -------
        bool
        Fix bspline knots to ensure that there is enough gap between neighbouring values returns true if something fixed (by shifting knot).

        Parameters
        ----------
        knots: TColStd_Array1OfReal

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_Curve_FixKnots(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeConstruct.ShapeConstruct_Curve_swiginit(self, _ShapeConstruct.new_ShapeConstruct_Curve())
    __swig_destroy__ = _ShapeConstruct.delete_ShapeConstruct_Curve

# Register ShapeConstruct_Curve in _ShapeConstruct:
_ShapeConstruct.ShapeConstruct_Curve_swigregister(ShapeConstruct_Curve)

def ShapeConstruct_Curve_FixKnots(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    knots: TColStd_HArray1OfReal

    Returns
    -------
    bool
    Fix bspline knots to ensure that there is enough gap between neighbouring values returns true if something fixed (by shifting knot).

    Parameters
    ----------
    knots: TColStd_Array1OfReal

    Returns
    -------
    bool

    """
    return _ShapeConstruct.ShapeConstruct_Curve_FixKnots(*args)

class ShapeConstruct_MakeTriangulation(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        pnts: TColgp_Array1OfPnt
        prec: float,optional
        	default value is 0.0

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        wire: TopoDS_Wire
        prec: float,optional
        	default value is 0.0

        Returns
        -------
        None

        """
        _ShapeConstruct.ShapeConstruct_MakeTriangulation_swiginit(self, _ShapeConstruct.new_ShapeConstruct_MakeTriangulation(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeConstruct.delete_ShapeConstruct_MakeTriangulation

# Register ShapeConstruct_MakeTriangulation in _ShapeConstruct:
_ShapeConstruct.ShapeConstruct_MakeTriangulation_swigregister(ShapeConstruct_MakeTriangulation)

class ShapeConstruct_ProjectCurveOnSurface(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_swiginit(self, _ShapeConstruct.new_ShapeConstruct_ProjectCurveOnSurface(*args))

    def GetAdjustOverDegenMode(self) -> "Standard_Integer":
        r"""GetAdjustOverDegenMode(ShapeConstruct_ProjectCurveOnSurface self) -> Standard_Integer"""
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_GetAdjustOverDegenMode(self)

    def SetAdjustOverDegenMode(self, value: "Standard_Integer") -> "void":
        r"""SetAdjustOverDegenMode(ShapeConstruct_ProjectCurveOnSurface self, Standard_Integer value)"""
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_SetAdjustOverDegenMode(self, value)

    def GetBuildCurveMode(self) -> "Standard_Boolean":
        r"""GetBuildCurveMode(ShapeConstruct_ProjectCurveOnSurface self) -> Standard_Boolean"""
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_GetBuildCurveMode(self)

    def SetBuildCurveMode(self, value: "Standard_Boolean") -> "void":
        r"""SetBuildCurveMode(ShapeConstruct_ProjectCurveOnSurface self, Standard_Boolean value)"""
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_SetBuildCurveMode(self, value)

    def Init(self, *args) -> "void":
        r"""
        Initializes the object with all necessary parameters, i.e. surface and precision.

        Parameters
        ----------
        surf: Geom_Surface
        preci: float

        Returns
        -------
        None
        Initializes the object with all necessary parameters, i.e. surface and precision.

        Parameters
        ----------
        surf: ShapeAnalysis_Surface
        preci: float

        Returns
        -------
        None

        """
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_Init(self, *args)

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        Computes the projection of 3d curve onto a surface using the specialized algorithm. returns false if projector fails, otherwise, if pcurve computed successfully, returns true. the output curve 2d is guaranteed to be same-parameter with input curve 3d on the interval [first, last]. if the output curve lies on a direct line the infinite line is returned, in the case same-parameter condition is satisfied. tolfirst and tollast are the tolerances at the ends of input curve 3d.

        Parameters
        ----------
        c3d: Geom_Curve
        First: float
        Last: float
        c2d: Geom2d_Curve
        TolFirst: float,optional
        	default value is -1
        TolLast: float,optional
        	default value is -1

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_Perform(self, *args)

    def PerformByProjLib(self, *args) -> "Standard_Boolean":
        r"""
        Computes the projection of 3d curve onto a surface using the standard algorithm from projlib. returns false if standard projector fails or raises an exception or cuts the curve by parametrical bounds of the surface. else, if pcurve computed successfully, returns true. the continuity, maxdeg and nbinterval are parameters of call to approx_curveonsurface. if nbinterval is equal to -1 (default), this value is computed depending on source 3d curve and surface.

        Parameters
        ----------
        c3d: Geom_Curve
        First: float
        Last: float
        c2d: Geom2d_Curve
        continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1
        maxdeg: int,optional
        	default value is 12
        nbinterval: int,optional
        	default value is -1

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_PerformByProjLib(self, *args)

    def SetPrecision(self, *args) -> "void":
        r"""
        Sets value for current precision.

        Parameters
        ----------
        preci: float

        Returns
        -------
        None

        """
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_SetPrecision(self, *args)

    def SetSurface(self, *args) -> "void":
        r"""
        Loads a surface (in the form of geom_surface) to project on.

        Parameters
        ----------
        surf: Geom_Surface

        Returns
        -------
        None
        Loads a surface (in the form of shapeanalysis_surface) to project on.

        Parameters
        ----------
        surf: ShapeAnalysis_Surface

        Returns
        -------
        None

        """
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_SetSurface(self, *args)

    def Status(self, *args) -> "Standard_Boolean":
        r"""
        Returns the status of last peform.

        Parameters
        ----------
        theStatus: ShapeExtend_Status

        Returns
        -------
        bool

        """
        return _ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_Status(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeConstruct_ProjectCurveOnSurface_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeConstruct.delete_ShapeConstruct_ProjectCurveOnSurface

# Register ShapeConstruct_ProjectCurveOnSurface in _ShapeConstruct:
_ShapeConstruct.ShapeConstruct_ProjectCurveOnSurface_swigregister(ShapeConstruct_ProjectCurveOnSurface)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRepBuilderAPI import *
from OCC.Core.TopoDS import *
from OCC.Core.ChFiDS import *
from OCC.Core.TopTools import *
from OCC.Core.ChFi2d import *
from OCC.Core.TopOpeBRepBuild import *
from OCC.Core.ChFi3d import *
from OCC.Core.Law import *
from OCC.Core.TColgp import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *


class BRepFilletAPI_LocalOperation(BRepBuilderAPI_MakeShape):
	def Abscissa(self, IC: int, V: TopoDS_Vertex) -> float: ...
	def Add(self, E: TopoDS_Edge) -> None: ...
	def Closed(self, IC: int) -> bool: ...
	def ClosedAndTangent(self, IC: int) -> bool: ...
	def Contour(self, E: TopoDS_Edge) -> int: ...
	def Edge(self, I: int, J: int) -> TopoDS_Edge: ...
	def FirstVertex(self, IC: int) -> TopoDS_Vertex: ...
	def LastVertex(self, IC: int) -> TopoDS_Vertex: ...
	def Length(self, IC: int) -> float: ...
	def NbContours(self) -> int: ...
	def NbEdges(self, I: int) -> int: ...
	def NbSurf(self, IC: int) -> int: ...
	def RelativeAbscissa(self, IC: int, V: TopoDS_Vertex) -> float: ...
	def Remove(self, E: TopoDS_Edge) -> None: ...
	def Reset(self) -> None: ...
	def ResetContour(self, IC: int) -> None: ...
	def Sect(self, IC: int, IS: int) -> ChFiDS_SecHArray1: ...
	def Simulate(self, IC: int) -> None: ...

class BRepFilletAPI_MakeFillet2d(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face) -> None: ...
	@overload
	def AddChamfer(self, E1: TopoDS_Edge, E2: TopoDS_Edge, D1: float, D2: float) -> TopoDS_Edge: ...
	@overload
	def AddChamfer(self, E: TopoDS_Edge, V: TopoDS_Vertex, D: float, Ang: float) -> TopoDS_Edge: ...
	def AddFillet(self, V: TopoDS_Vertex, Radius: float) -> TopoDS_Edge: ...
	def BasisEdge(self, E: TopoDS_Edge) -> TopoDS_Edge: ...
	def Build(self) -> None: ...
	def ChamferEdges(self) -> TopTools_SequenceOfShape: ...
	def DescendantEdge(self, E: TopoDS_Edge) -> TopoDS_Edge: ...
	def FilletEdges(self) -> TopTools_SequenceOfShape: ...
	def HasDescendant(self, E: TopoDS_Edge) -> bool: ...
	@overload
	def Init(self, F: TopoDS_Face) -> None: ...
	@overload
	def Init(self, RefFace: TopoDS_Face, ModFace: TopoDS_Face) -> None: ...
	def IsModified(self, E: TopoDS_Edge) -> bool: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@overload
	def ModifyChamfer(self, Chamfer: TopoDS_Edge, E1: TopoDS_Edge, E2: TopoDS_Edge, D1: float, D2: float) -> TopoDS_Edge: ...
	@overload
	def ModifyChamfer(self, Chamfer: TopoDS_Edge, E: TopoDS_Edge, D: float, Ang: float) -> TopoDS_Edge: ...
	def ModifyFillet(self, Fillet: TopoDS_Edge, Radius: float) -> TopoDS_Edge: ...
	def NbChamfer(self) -> int: ...
	def NbCurves(self) -> int: ...
	def NbFillet(self) -> int: ...
	def NewEdges(self, I: int) -> TopTools_ListOfShape: ...
	def RemoveChamfer(self, Chamfer: TopoDS_Edge) -> TopoDS_Vertex: ...
	def RemoveFillet(self, Fillet: TopoDS_Edge) -> TopoDS_Vertex: ...
	def Status(self) -> ChFi2d_ConstructionError: ...

class BRepFilletAPI_MakeChamfer(BRepFilletAPI_LocalOperation):
	def __init__(self, S: TopoDS_Shape) -> None: ...
	def Abscissa(self, IC: int, V: TopoDS_Vertex) -> float: ...
	@overload
	def Add(self, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, Dis: float, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, Dis1: float, Dis2: float, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def AddDA(self, Dis: float, Angle: float, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def Build(self) -> None: ...
	def Builder(self) -> TopOpeBRepBuild_HBuilder: ...
	def Closed(self, IC: int) -> bool: ...
	def ClosedAndTangent(self, IC: int) -> bool: ...
	def Contour(self, E: TopoDS_Edge) -> int: ...
	def Dists(self, IC: int) -> Tuple[float, float]: ...
	def Edge(self, I: int, J: int) -> TopoDS_Edge: ...
	def FirstVertex(self, IC: int) -> TopoDS_Vertex: ...
	def Generated(self, EorV: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GetDist(self, IC: int) -> float: ...
	def GetDistAngle(self, IC: int) -> Tuple[float, float]: ...
	def IsDeleted(self, F: TopoDS_Shape) -> bool: ...
	def IsDistanceAngle(self, IC: int) -> bool: ...
	def IsSymetric(self, IC: int) -> bool: ...
	def IsTwoDistances(self, IC: int) -> bool: ...
	def LastVertex(self, IC: int) -> TopoDS_Vertex: ...
	def Length(self, IC: int) -> float: ...
	def Modified(self, F: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def NbContours(self) -> int: ...
	def NbEdges(self, I: int) -> int: ...
	def NbSurf(self, IC: int) -> int: ...
	def RelativeAbscissa(self, IC: int, V: TopoDS_Vertex) -> float: ...
	def Remove(self, E: TopoDS_Edge) -> None: ...
	def Reset(self) -> None: ...
	def ResetContour(self, IC: int) -> None: ...
	def Sect(self, IC: int, IS: int) -> ChFiDS_SecHArray1: ...
	def SetDist(self, Dis: float, IC: int, F: TopoDS_Face) -> None: ...
	def SetDistAngle(self, Dis: float, Angle: float, IC: int, F: TopoDS_Face) -> None: ...
	def SetDists(self, Dis1: float, Dis2: float, IC: int, F: TopoDS_Face) -> None: ...
	def SetMode(self, theMode: ChFiDS_ChamfMode) -> None: ...
	def Simulate(self, IC: int) -> None: ...

class BRepFilletAPI_MakeFillet(BRepFilletAPI_LocalOperation):
	def __init__(self, S: TopoDS_Shape, FShape: Optional[ChFi3d_FilletShape] = ChFi3d_Rational) -> None: ...
	def Abscissa(self, IC: int, V: TopoDS_Vertex) -> float: ...
	@overload
	def Add(self, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, Radius: float, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, R1: float, R2: float, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, L: Law_Function, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, UandR: TColgp_Array1OfPnt2d, E: TopoDS_Edge) -> None: ...
	def BadShape(self) -> TopoDS_Shape: ...
	def Build(self) -> None: ...
	def Builder(self) -> TopOpeBRepBuild_HBuilder: ...
	def Closed(self, IC: int) -> bool: ...
	def ClosedAndTangent(self, IC: int) -> bool: ...
	def ComputedSurface(self, IC: int, IS: int) -> Geom_Surface: ...
	def Contour(self, E: TopoDS_Edge) -> int: ...
	def Edge(self, I: int, J: int) -> TopoDS_Edge: ...
	def FaultyContour(self, I: int) -> int: ...
	def FaultyVertex(self, IV: int) -> TopoDS_Vertex: ...
	def FirstVertex(self, IC: int) -> TopoDS_Vertex: ...
	def Generated(self, EorV: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GetBounds(self, IC: int, E: TopoDS_Edge) -> Tuple[bool, float, float]: ...
	def GetFilletShape(self) -> ChFi3d_FilletShape: ...
	def GetLaw(self, IC: int, E: TopoDS_Edge) -> Law_Function: ...
	def HasResult(self) -> bool: ...
	@overload
	def IsConstant(self, IC: int) -> bool: ...
	@overload
	def IsConstant(self, IC: int, E: TopoDS_Edge) -> bool: ...
	def IsDeleted(self, F: TopoDS_Shape) -> bool: ...
	def LastVertex(self, IC: int) -> TopoDS_Vertex: ...
	def Length(self, IC: int) -> float: ...
	def Modified(self, F: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def NbComputedSurfaces(self, IC: int) -> int: ...
	def NbContours(self) -> int: ...
	def NbEdges(self, I: int) -> int: ...
	def NbFaultyContours(self) -> int: ...
	def NbFaultyVertices(self) -> int: ...
	def NbSurf(self, IC: int) -> int: ...
	def NbSurfaces(self) -> int: ...
	def NewFaces(self, I: int) -> TopTools_ListOfShape: ...
	@overload
	def Radius(self, IC: int) -> float: ...
	@overload
	def Radius(self, IC: int, E: TopoDS_Edge) -> float: ...
	def RelativeAbscissa(self, IC: int, V: TopoDS_Vertex) -> float: ...
	def Remove(self, E: TopoDS_Edge) -> None: ...
	def Reset(self) -> None: ...
	def ResetContour(self, IC: int) -> None: ...
	def Sect(self, IC: int, IS: int) -> ChFiDS_SecHArray1: ...
	def SetContinuity(self, InternalContinuity: GeomAbs_Shape, AngularTolerance: float) -> None: ...
	def SetFilletShape(self, FShape: ChFi3d_FilletShape) -> None: ...
	def SetLaw(self, IC: int, E: TopoDS_Edge, L: Law_Function) -> None: ...
	def SetParams(self, Tang: float, Tesp: float, T2d: float, TApp3d: float, TolApp2d: float, Fleche: float) -> None: ...
	@overload
	def SetRadius(self, Radius: float, IC: int, IinC: int) -> None: ...
	@overload
	def SetRadius(self, R1: float, R2: float, IC: int, IinC: int) -> None: ...
	@overload
	def SetRadius(self, L: Law_Function, IC: int, IinC: int) -> None: ...
	@overload
	def SetRadius(self, UandR: TColgp_Array1OfPnt2d, IC: int, IinC: int) -> None: ...
	@overload
	def SetRadius(self, Radius: float, IC: int, E: TopoDS_Edge) -> None: ...
	@overload
	def SetRadius(self, Radius: float, IC: int, V: TopoDS_Vertex) -> None: ...
	def Simulate(self, IC: int) -> None: ...
	def StripeStatus(self, IC: int) -> ChFiDS_ErrorStatus: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.IntRes2d import *
from OCC.Core.TColStd import *
from OCC.Core.math import *
from OCC.Core.GeomAbs import *


class IntCurve_IConicTool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, IT: IntCurve_IConicTool) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, P: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, T: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, T: gp_Vec2d, N: gp_Vec2d) -> None: ...
	def Distance(self, P: gp_Pnt2d) -> float: ...
	def FindParameter(self, P: gp_Pnt2d) -> float: ...
	def GradDistance(self, P: gp_Pnt2d) -> gp_Vec2d: ...
	def Value(self, X: float) -> gp_Pnt2d: ...

class IntCurve_IntConicConic(IntRes2d_Intersection):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L1: gp_Lin2d, D1: IntRes2d_Domain, L2: gp_Lin2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, DL: IntRes2d_Domain, C: gp_Circ2d, DC: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, DL: IntRes2d_Domain, E: gp_Elips2d, DE: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, DL: IntRes2d_Domain, P: gp_Parab2d, DP: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, DL: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C1: gp_Circ2d, D1: IntRes2d_Domain, C2: gp_Circ2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, DC: IntRes2d_Domain, E: gp_Elips2d, DE: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, DC: IntRes2d_Domain, P: gp_Parab2d, DP: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, DC: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, E1: gp_Elips2d, D1: IntRes2d_Domain, E2: gp_Elips2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d, DE: IntRes2d_Domain, P: gp_Parab2d, DP: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d, DE: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, P1: gp_Parab2d, D1: IntRes2d_Domain, P2: gp_Parab2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, P: gp_Parab2d, DP: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, H1: gp_Hypr2d, D1: IntRes2d_Domain, H2: gp_Hypr2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L1: gp_Lin2d, D1: IntRes2d_Domain, L2: gp_Lin2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, DL: IntRes2d_Domain, C: gp_Circ2d, DC: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, DL: IntRes2d_Domain, E: gp_Elips2d, DE: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, DL: IntRes2d_Domain, P: gp_Parab2d, DP: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, DL: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C1: gp_Circ2d, D1: IntRes2d_Domain, C2: gp_Circ2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C: gp_Circ2d, DC: IntRes2d_Domain, E: gp_Elips2d, DE: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C: gp_Circ2d, DC: IntRes2d_Domain, P: gp_Parab2d, DP: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C: gp_Circ2d, DC: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, E1: gp_Elips2d, D1: IntRes2d_Domain, E2: gp_Elips2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, E: gp_Elips2d, DE: IntRes2d_Domain, P: gp_Parab2d, DP: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, E: gp_Elips2d, DE: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, P1: gp_Parab2d, D1: IntRes2d_Domain, P2: gp_Parab2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, P: gp_Parab2d, DP: IntRes2d_Domain, H: gp_Hypr2d, DH: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, H1: gp_Hypr2d, D1: IntRes2d_Domain, H2: gp_Hypr2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...

class IntCurve_IntImpConicParConic(IntRes2d_Intersection):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, ITool: IntCurve_IConicTool, Dom1: IntRes2d_Domain, PCurve: IntCurve_PConic, Dom2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	def And_Domaine_Objet1_Intersections(self, TheImpTool: IntCurve_IConicTool, TheParCurve: IntCurve_PConic, TheImpCurveDomain: IntRes2d_Domain, TheParCurveDomain: IntRes2d_Domain, Inter2_And_Domain2: TColStd_Array1OfReal, Inter1: TColStd_Array1OfReal, Resultat1: TColStd_Array1OfReal, Resultat2: TColStd_Array1OfReal, EpsNul: float) -> int: ...
	def FindU(self, parameter: float, point: gp_Pnt2d, TheParCurev: IntCurve_PConic, TheImpTool: IntCurve_IConicTool) -> float: ...
	def FindV(self, parameter: float, point: gp_Pnt2d, TheImpTool: IntCurve_IConicTool, ParCurve: IntCurve_PConic, TheParCurveDomain: IntRes2d_Domain, V0: float, V1: float, Tolerance: float) -> float: ...
	def Perform(self, ITool: IntCurve_IConicTool, Dom1: IntRes2d_Domain, PCurve: IntCurve_PConic, Dom2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...

class IntCurve_MyImpParToolOfIntImpConicParConic(math_FunctionWithDerivative):
	def __init__(self, IT: IntCurve_IConicTool, PC: IntCurve_PConic) -> None: ...
	def Derivative(self, Param: float) -> Tuple[bool, float]: ...
	def Value(self, Param: float) -> Tuple[bool, float]: ...
	def Values(self, Param: float) -> Tuple[bool, float, float]: ...

class IntCurve_PConic:
	@overload
	def __init__(self, PC: IntCurve_PConic) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, P: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	def Accuracy(self) -> int: ...
	def Axis2(self) -> gp_Ax22d: ...
	def EpsX(self) -> float: ...
	def Param1(self) -> float: ...
	def Param2(self) -> float: ...
	def SetAccuracy(self, Nb: int) -> None: ...
	def SetEpsX(self, EpsDist: float) -> None: ...
	def TypeCurve(self) -> GeomAbs_CurveType: ...

class IntCurve_PConicTool:
	@staticmethod
	def D1(C: IntCurve_PConic, U: float, P: gp_Pnt2d, T: gp_Vec2d) -> None: ...
	@staticmethod
	def D2(C: IntCurve_PConic, U: float, P: gp_Pnt2d, T: gp_Vec2d, N: gp_Vec2d) -> None: ...
	@staticmethod
	def EpsX(C: IntCurve_PConic) -> float: ...
	@overload
	@staticmethod
	def NbSamples(C: IntCurve_PConic) -> int: ...
	@overload
	@staticmethod
	def NbSamples(C: IntCurve_PConic, U0: float, U1: float) -> int: ...
	@staticmethod
	def Value(C: IntCurve_PConic, X: float) -> gp_Pnt2d: ...

class IntCurve_ProjectOnPConicTool:
	@overload
	@staticmethod
	def FindParameter(C: IntCurve_PConic, Pnt: gp_Pnt2d, Tol: float) -> float: ...
	@overload
	@staticmethod
	def FindParameter(C: IntCurve_PConic, Pnt: gp_Pnt2d, LowParameter: float, HighParameter: float, Tol: float) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

IntCurve_PConicTool_D1 = IntCurve_PConicTool.D1
IntCurve_PConicTool_D2 = IntCurve_PConicTool.D2
IntCurve_PConicTool_EpsX = IntCurve_PConicTool.EpsX
IntCurve_PConicTool_NbSamples = IntCurve_PConicTool.NbSamples
IntCurve_PConicTool_NbSamples = IntCurve_PConicTool.NbSamples
IntCurve_PConicTool_Value = IntCurve_PConicTool.Value
IntCurve_ProjectOnPConicTool_FindParameter = IntCurve_ProjectOnPConicTool.FindParameter
IntCurve_ProjectOnPConicTool_FindParameter = IntCurve_ProjectOnPConicTool.FindParameter



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Bnd import *


class Intf_Array1OfLin:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> gp_Lin: ...
    def __setitem__(self, index: int, value: gp_Lin) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[gp_Lin]: ...
    def next(self) -> gp_Lin: ...
    __next__ = next
    def Init(self, theValue: gp_Lin) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> gp_Lin: ...
    def Last(self) -> gp_Lin: ...
    def Value(self, theIndex: int) -> gp_Lin: ...
    def SetValue(self, theIndex: int, theValue: gp_Lin) -> None: ...

class Intf_SeqOfSectionLine:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Intf_SectionLine: ...
    def Last(self) -> Intf_SectionLine: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Intf_SectionLine) -> Intf_SectionLine: ...
    def Prepend(self, theItem: Intf_SectionLine) -> Intf_SectionLine: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Intf_SectionLine: ...
    def SetValue(self, theIndex: int, theValue: Intf_SectionLine) -> None: ...

class Intf_SeqOfSectionPoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Intf_SectionPoint: ...
    def Last(self) -> Intf_SectionPoint: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Intf_SectionPoint) -> Intf_SectionPoint: ...
    def Prepend(self, theItem: Intf_SectionPoint) -> Intf_SectionPoint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Intf_SectionPoint: ...
    def SetValue(self, theIndex: int, theValue: Intf_SectionPoint) -> None: ...

class Intf_SeqOfTangentZone:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Intf_TangentZone: ...
    def Last(self) -> Intf_TangentZone: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Intf_TangentZone) -> Intf_TangentZone: ...
    def Prepend(self, theItem: Intf_TangentZone) -> Intf_TangentZone: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Intf_TangentZone: ...
    def SetValue(self, theIndex: int, theValue: Intf_TangentZone) -> None: ...

class Intf_PIType(IntEnum):
	Intf_EXTERNAL: int = ...
	Intf_FACE: int = ...
	Intf_EDGE: int = ...
	Intf_VERTEX: int = ...
Intf_EXTERNAL = Intf_PIType.Intf_EXTERNAL
Intf_FACE = Intf_PIType.Intf_FACE
Intf_EDGE = Intf_PIType.Intf_EDGE
Intf_VERTEX = Intf_PIType.Intf_VERTEX

class intf:
	@staticmethod
	def Contain(P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, ThePnt: gp_Pnt) -> bool: ...
	@staticmethod
	def PlaneEquation(P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, NormalVector: gp_XYZ) -> float: ...

class Intf_Interference:
	def Contains(self, ThePnt: Intf_SectionPoint) -> bool: ...
	def Dump(self) -> None: ...
	def GetTolerance(self) -> float: ...
	@overload
	def Insert(self, TheZone: Intf_TangentZone) -> bool: ...
	@overload
	def Insert(self, pdeb: Intf_SectionPoint, pfin: Intf_SectionPoint) -> None: ...
	def LineValue(self, Index: int) -> Intf_SectionLine: ...
	def NbSectionLines(self) -> int: ...
	def NbSectionPoints(self) -> int: ...
	def NbTangentZones(self) -> int: ...
	def PntValue(self, Index: int) -> Intf_SectionPoint: ...
	def ZoneValue(self, Index: int) -> Intf_TangentZone: ...

class Intf_Polygon2d:
	def Bounding(self) -> Bnd_Box2d: ...
	def Closed(self) -> bool: ...
	def DeflectionOverEstimation(self) -> float: ...
	def NbSegments(self) -> int: ...
	def Segment(self, theIndex: int, theBegin: gp_Pnt2d, theEnd: gp_Pnt2d) -> None: ...

class Intf_SectionLine:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Other: Intf_SectionLine) -> None: ...
	@overload
	def Append(self, Pi: Intf_SectionPoint) -> None: ...
	@overload
	def Append(self, LS: Intf_SectionLine) -> None: ...
	def Close(self) -> None: ...
	def Contains(self, ThePI: Intf_SectionPoint) -> bool: ...
	def Dump(self, Indent: int) -> None: ...
	def GetPoint(self, Index: int) -> Intf_SectionPoint: ...
	def IsClosed(self) -> bool: ...
	def IsEnd(self, ThePI: Intf_SectionPoint) -> int: ...
	def IsEqual(self, Other: Intf_SectionLine) -> bool: ...
	def NumberOfPoints(self) -> int: ...
	@overload
	def Prepend(self, Pi: Intf_SectionPoint) -> None: ...
	@overload
	def Prepend(self, LS: Intf_SectionLine) -> None: ...
	def Reverse(self) -> None: ...

class Intf_SectionPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Where: gp_Pnt, DimeO: Intf_PIType, AddrO1: int, AddrO2: int, ParamO: float, DimeT: Intf_PIType, AddrT1: int, AddrT2: int, ParamT: float, Incid: float) -> None: ...
	@overload
	def __init__(self, Where: gp_Pnt2d, DimeO: Intf_PIType, AddrO1: int, ParamO: float, DimeT: Intf_PIType, AddrT1: int, ParamT: float, Incid: float) -> None: ...
	def Dump(self, Indent: int) -> None: ...
	def Incidence(self) -> float: ...
	@overload
	def InfoFirst(self, Dim: Intf_PIType) -> Tuple[int, int, float]: ...
	@overload
	def InfoFirst(self, Dim: Intf_PIType) -> Tuple[int, float]: ...
	@overload
	def InfoSecond(self, Dim: Intf_PIType) -> Tuple[int, int, float]: ...
	@overload
	def InfoSecond(self, Dim: Intf_PIType) -> Tuple[int, float]: ...
	def IsEqual(self, Other: Intf_SectionPoint) -> bool: ...
	def IsOnSameEdge(self, Other: Intf_SectionPoint) -> bool: ...
	def Merge(self, Other: Intf_SectionPoint) -> None: ...
	def ParamOnFirst(self) -> float: ...
	def ParamOnSecond(self) -> float: ...
	def Pnt(self) -> gp_Pnt: ...
	def TypeOnFirst(self) -> Intf_PIType: ...
	def TypeOnSecond(self) -> Intf_PIType: ...

class Intf_TangentZone:
	def __init__(self) -> None: ...
	@overload
	def Append(self, Pi: Intf_SectionPoint) -> None: ...
	@overload
	def Append(self, Tzi: Intf_TangentZone) -> None: ...
	def Contains(self, ThePI: Intf_SectionPoint) -> bool: ...
	def Dump(self, Indent: int) -> None: ...
	def GetPoint(self, Index: int) -> Intf_SectionPoint: ...
	def HasCommonRange(self, Other: Intf_TangentZone) -> bool: ...
	def InfoFirst(self) -> Tuple[int, float, int, float]: ...
	def InfoSecond(self) -> Tuple[int, float, int, float]: ...
	def Insert(self, Pi: Intf_SectionPoint) -> bool: ...
	def InsertAfter(self, Index: int, Pi: Intf_SectionPoint) -> None: ...
	def InsertBefore(self, Index: int, Pi: Intf_SectionPoint) -> None: ...
	def IsEqual(self, Other: Intf_TangentZone) -> bool: ...
	def NumberOfPoints(self) -> int: ...
	def ParamOnFirst(self) -> Tuple[float, float]: ...
	def ParamOnSecond(self) -> Tuple[float, float]: ...
	def PolygonInsert(self, Pi: Intf_SectionPoint) -> None: ...
	def RangeContains(self, ThePI: Intf_SectionPoint) -> bool: ...

class Intf_Tool:
	def __init__(self) -> None: ...
	def BeginParam(self, SegmentNum: int) -> float: ...
	def EndParam(self, SegmentNum: int) -> float: ...
	def Hypr2dBox(self, theHypr2d: gp_Hypr2d, bounding: Bnd_Box2d, boxHypr: Bnd_Box2d) -> None: ...
	def HyprBox(self, theHypr: gp_Hypr, bounding: Bnd_Box, boxHypr: Bnd_Box) -> None: ...
	def Lin2dBox(self, theLin2d: gp_Lin2d, bounding: Bnd_Box2d, boxLin: Bnd_Box2d) -> None: ...
	def LinBox(self, theLin: gp_Lin, bounding: Bnd_Box, boxLin: Bnd_Box) -> None: ...
	def NbSegments(self) -> int: ...
	def Parab2dBox(self, theParab2d: gp_Parab2d, bounding: Bnd_Box2d, boxHypr: Bnd_Box2d) -> None: ...
	def ParabBox(self, theParab: gp_Parab, bounding: Bnd_Box, boxHypr: Bnd_Box) -> None: ...

class Intf_InterferencePolygon2d(Intf_Interference):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Obje1: Intf_Polygon2d, Obje2: Intf_Polygon2d) -> None: ...
	@overload
	def __init__(self, Obje: Intf_Polygon2d) -> None: ...
	@overload
	def Perform(self, Obje1: Intf_Polygon2d, Obje2: Intf_Polygon2d) -> None: ...
	@overload
	def Perform(self, Obje: Intf_Polygon2d) -> None: ...
	def Pnt2dValue(self, Index: int) -> gp_Pnt2d: ...

# harray1 classes
# harray2 classes
# hsequence classes

intf_Contain = intf.Contain
intf_PlaneEquation = intf.PlaneEquation



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.GccEnt import *
from OCC.Core.gp import *
from OCC.Core.GccInt import *


class GccAna_Circ2d2TanOn:
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, OnLine: gp_Lin2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedLin, OnLine: gp_Lin2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Qualified2: GccEnt_QualifiedLin, OnLine: gp_Lin2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Point2: gp_Pnt2d, OnLine: gp_Lin2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Point2: gp_Pnt2d, OnLine: gp_Lin2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, Point2: gp_Pnt2d, OnLine: gp_Lin2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, OnCirc: gp_Circ2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedLin, OnCirc: gp_Circ2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Point2: gp_Pnt2d, OnCirc: gp_Circ2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Qualified2: GccEnt_QualifiedLin, OnCirc: gp_Circ2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Point2: gp_Pnt2d, OnCirc: gp_Circ2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, Point2: gp_Pnt2d, OnCirc: gp_Circ2d, Tolerance: float) -> None: ...
	def CenterOn3(self, Index: int, PntArg: gp_Pnt2d) -> float: ...
	def IsDone(self) -> bool: ...
	def IsTheSame1(self, Index: int) -> bool: ...
	def IsTheSame2(self, Index: int) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def Tangency2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Circ2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position, Qualif2: GccEnt_Position) -> None: ...

class GccAna_Circ2d2TanRad:
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedLin, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Point2: gp_Pnt2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Point2: gp_Pnt2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Qualified2: GccEnt_QualifiedLin, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, Point2: gp_Pnt2d, Radius: float, Tolerance: float) -> None: ...
	def IsDone(self) -> bool: ...
	def IsTheSame1(self, Index: int) -> bool: ...
	def IsTheSame2(self, Index: int) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def Tangency2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Circ2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position, Qualif2: GccEnt_Position) -> None: ...

class GccAna_Circ2d3Tan:
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, Qualified3: GccEnt_QualifiedCirc, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, Qualified3: GccEnt_QualifiedLin, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedLin, Qualified3: GccEnt_QualifiedLin, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Qualified2: GccEnt_QualifiedLin, Qualified3: GccEnt_QualifiedLin, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, Point3: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedLin, Point3: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Qualified2: GccEnt_QualifiedLin, Point3: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Point2: gp_Pnt2d, Point3: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, Point2: gp_Pnt2d, Point3: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, Point2: gp_Pnt2d, Point3: gp_Pnt2d, Tolerance: float) -> None: ...
	def IsDone(self) -> bool: ...
	def IsTheSame1(self, Index: int) -> bool: ...
	def IsTheSame2(self, Index: int) -> bool: ...
	def IsTheSame3(self, Index: int) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def Tangency2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def Tangency3(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Circ2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position, Qualif2: GccEnt_Position, Qualif3: GccEnt_Position) -> None: ...

class GccAna_Circ2dBisec:
	def __init__(self, Circ1: gp_Circ2d, Circ2: gp_Circ2d) -> None: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def ThisSolution(self, Index: int) -> GccInt_Bisec: ...

class GccAna_Circ2dTanCen:
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Pcenter: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Linetan: gp_Lin2d, Pcenter: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, Pcenter: gp_Pnt2d) -> None: ...
	def IsDone(self) -> bool: ...
	def IsTheSame1(self, Index: int) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Circ2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position) -> None: ...

class GccAna_Circ2dTanOnRad:
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, OnLine: gp_Lin2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, OnLine: gp_Lin2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, OnLine: gp_Lin2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, OnCirc: gp_Circ2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedLin, OnCirc: gp_Circ2d, Radius: float, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Point1: gp_Pnt2d, OnCirc: gp_Circ2d, Radius: float, Tolerance: float) -> None: ...
	def CenterOn3(self, Index: int, PntSol: gp_Pnt2d) -> float: ...
	def IsDone(self) -> bool: ...
	def IsTheSame1(self, Index: int) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Circ2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position) -> None: ...

class GccAna_CircLin2dBisec:
	def __init__(self, Circle: gp_Circ2d, Line: gp_Lin2d) -> None: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def ThisSolution(self, Index: int) -> GccInt_Bisec: ...

class GccAna_CircPnt2dBisec:
	@overload
	def __init__(self, Circle1: gp_Circ2d, Point2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, Circle1: gp_Circ2d, Point2: gp_Pnt2d, Tolerance: float) -> None: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def ThisSolution(self, Index: int) -> GccInt_Bisec: ...

class GccAna_Lin2d2Tan:
	@overload
	def __init__(self, ThePoint1: gp_Pnt2d, ThePoint2: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, ThePoint: gp_Pnt2d, Tolerance: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Qualified2: GccEnt_QualifiedCirc, Tolerance: float) -> None: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def Tangency2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Lin2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position, Qualif2: GccEnt_Position) -> None: ...

class GccAna_Lin2dBisec:
	def __init__(self, Lin1: gp_Lin2d, Lin2: gp_Lin2d) -> None: ...
	def Intersection1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def Intersection2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def ThisSolution(self, Index: int) -> gp_Lin2d: ...

class GccAna_Lin2dTanObl:
	@overload
	def __init__(self, ThePoint: gp_Pnt2d, TheLine: gp_Lin2d, TheAngle: float) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, TheLine: gp_Lin2d, TheAngle: float) -> None: ...
	def Intersection2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Lin2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position) -> None: ...

class GccAna_Lin2dTanPar:
	@overload
	def __init__(self, ThePoint: gp_Pnt2d, Lin1: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, Lin1: gp_Lin2d) -> None: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, Pnt: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Lin2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position) -> None: ...

class GccAna_Lin2dTanPer:
	@overload
	def __init__(self, ThePnt: gp_Pnt2d, TheLin: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, ThePnt: gp_Pnt2d, TheCircle: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, TheLin: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, Qualified1: GccEnt_QualifiedCirc, TheCircle: gp_Circ2d) -> None: ...
	def Intersection2(self, Index: int, PntSol: gp_Pnt2d) -> Tuple[float, float]: ...
	def IsDone(self) -> bool: ...
	def NbSolutions(self) -> int: ...
	def Tangency1(self, Index: int, Pnt: gp_Pnt2d) -> Tuple[float, float]: ...
	def ThisSolution(self, Index: int) -> gp_Lin2d: ...
	def WhichQualifier(self, Index: int, Qualif1: GccEnt_Position) -> None: ...

class GccAna_LinPnt2dBisec:
	def __init__(self, Line1: gp_Lin2d, Point2: gp_Pnt2d) -> None: ...
	def IsDone(self) -> bool: ...
	def ThisSolution(self) -> GccInt_Bisec: ...

class GccAna_Pnt2dBisec:
	def __init__(self, Point1: gp_Pnt2d, Point2: gp_Pnt2d) -> None: ...
	def HasSolution(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def ThisSolution(self) -> gp_Lin2d: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *
from OCC.Core.StepData import *
from OCC.Core.StepBasic import *
from OCC.Core.StepShape import *
from OCC.Core.StepDimTol import *
from OCC.Core.StepRepr import *
from OCC.Core.StepAP214 import *


class StepAP242_IdAttribute(Standard_Transient):
	def __init__(self) -> None: ...
	def AttributeValue(self) -> TCollection_HAsciiString: ...
	def IdentifiedItem(self) -> StepAP242_IdAttributeSelect: ...
	def Init(self, theAttributeValue: TCollection_HAsciiString, theIdentifiedItem: StepAP242_IdAttributeSelect) -> None: ...
	def SetAttributeValue(self, theAttributeValue: TCollection_HAsciiString) -> None: ...
	def SetIdentifiedItem(self, theIdentifiedItem: StepAP242_IdAttributeSelect) -> None: ...

class StepAP242_IdAttributeSelect(StepData_SelectType):
	def __init__(self) -> None: ...
	def Action(self) -> StepBasic_Action: ...
	def Address(self) -> StepBasic_Address: ...
	def ApplicationContext(self) -> StepBasic_ApplicationContext: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DimensionalSize(self) -> StepShape_DimensionalSize: ...
	def GeometricTolerance(self) -> StepDimTol_GeometricTolerance: ...
	def Group(self) -> StepBasic_Group: ...
	def ProductCategory(self) -> StepBasic_ProductCategory: ...
	def PropertyDefinition(self) -> StepRepr_PropertyDefinition: ...
	def Representation(self) -> StepRepr_Representation: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...
	def ShapeAspectRelationship(self) -> StepRepr_ShapeAspectRelationship: ...

class StepAP242_ItemIdentifiedRepresentationUsage(Standard_Transient):
	def __init__(self) -> None: ...
	def Definition(self) -> StepAP242_ItemIdentifiedRepresentationUsageDefinition: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def IdentifiedItem(self) -> StepRepr_HArray1OfRepresentationItem: ...
	def IdentifiedItemValue(self, num: int) -> StepRepr_RepresentationItem: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theDefinition: StepAP242_ItemIdentifiedRepresentationUsageDefinition, theUsedRepresentation: StepRepr_Representation, theIdentifiedItem: StepRepr_HArray1OfRepresentationItem) -> None: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def NbIdentifiedItem(self) -> int: ...
	def SetDefinition(self, theDefinition: StepAP242_ItemIdentifiedRepresentationUsageDefinition) -> None: ...
	def SetDescription(self, theDescription: TCollection_HAsciiString) -> None: ...
	def SetIdentifiedItem(self, theIdentifiedItem: StepRepr_HArray1OfRepresentationItem) -> None: ...
	def SetIdentifiedItemValue(self, num: int, theItem: StepRepr_RepresentationItem) -> None: ...
	def SetName(self, theName: TCollection_HAsciiString) -> None: ...
	def SetUsedRepresentation(self, theUsedRepresentation: StepRepr_Representation) -> None: ...
	def UsedRepresentation(self) -> StepRepr_Representation: ...

class StepAP242_ItemIdentifiedRepresentationUsageDefinition(StepData_SelectType):
	def __init__(self) -> None: ...
	def AppliedApprovalAssignment(self) -> StepAP214_AppliedApprovalAssignment: ...
	def AppliedDateAndTimeAssignment(self) -> StepAP214_AppliedDateAndTimeAssignment: ...
	def AppliedDateAssignment(self) -> StepAP214_AppliedDateAssignment: ...
	def AppliedDocumentReference(self) -> StepAP214_AppliedDocumentReference: ...
	def AppliedExternalIdentificationAssignment(self) -> StepAP214_AppliedExternalIdentificationAssignment: ...
	def AppliedGroupAssignment(self) -> StepAP214_AppliedGroupAssignment: ...
	def AppliedOrganizationAssignment(self) -> StepAP214_AppliedOrganizationAssignment: ...
	def AppliedPersonAndOrganizationAssignment(self) -> StepAP214_AppliedPersonAndOrganizationAssignment: ...
	def AppliedSecurityClassificationAssignment(self) -> StepAP214_AppliedSecurityClassificationAssignment: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DimensionalSize(self) -> StepShape_DimensionalSize: ...
	def GeneralProperty(self) -> StepBasic_GeneralProperty: ...
	def GeometricTolerance(self) -> StepDimTol_GeometricTolerance: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def PropertyDefinition(self) -> StepRepr_PropertyDefinition: ...
	def PropertyDefinitionRelationship(self) -> StepRepr_PropertyDefinitionRelationship: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...
	def ShapeAspectRelationship(self) -> StepRepr_ShapeAspectRelationship: ...

class StepAP242_DraughtingModelItemAssociation(StepAP242_ItemIdentifiedRepresentationUsage):
	def __init__(self) -> None: ...

class StepAP242_GeometricItemSpecificUsage(StepAP242_ItemIdentifiedRepresentationUsage):
	def __init__(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

